**Example 1: 实例重启**

实例重启

Input: 

```
tccli ecm RebootInstances --cli-unfold-argument  \
    --InstanceIdSet ein-496721al ein-438242bp
```

Output: 
```
{
    "Response": {
        "RequestId": "d40cdb72-7bc0-4b48-b3aa-djl3424-a6482"
    }
}
```

